@@ -13,8 +13,11 @@ import pkg_resources
 import aiohttp
 import aiohttp.web
 from packaging import version
+
 from .http_client import HttpClient
 from .mikrotik import MikrotikApiError
+from .ssh_client import SshClient
+import asyncssh  # has to come after ssh_client import to suppress warnings
 from prometheus_client.exposition import generate_latest
 
 # Set an IPv6 enabled interface for utility code to use.
@@ -460,3 +463,59 @@ async def mikrotik_api_probe(host, mikrotik_api_cls, creds, **kwargs):
                 except asyncio.CancelledError:
                     pass
     return client
+
+
+async def _ssh_probe(host, port, ssh_client_cls, creds, raise_errors, **kwargs):
+    """Probe the SSL server of a host using (username, password) tuples."""
+    client = None
+    err = None
+    for cred in creds:
+        ssh_client = ssh_client_cls(host,
+                                    port=port,
+                                    username=cred[0],
+                                    password=cred[1],
+                                    **kwargs)
+        try:
+            await asyncio.wait_for(ssh_client._open(), 5.0)
+            client = ssh_client
+            break
+        except asyncssh.PermissionDenied as err:
+            await ssh_client.close()
+        except (asyncssh.Error, OSError, asyncio.TimeoutError) as err:
+            await ssh_client.close()
+            break  # connectivity error, no point in trying other creds
+        except Exception:
+            await ssh_client.close()
+            raise
+    if err and raise_errors:
+        raise err
+    return client
+
+
+async def ssh_probe(host, ssh_client_cls, creds, raise_errors=False, **kwargs):
+    """Try to connect to a SSH server using list of (username, password) credentials."""
+    # it's done this way to support multiple ports in the future
+    pend = [
+        asyncio.create_task(x) for x in
+        [_ssh_probe(host, None, ssh_client_cls, creds, raise_errors, **kwargs)]
+    ]
+    client = None
+    while pend:
+        done, pend = await asyncio.wait(pend, return_when=asyncio.FIRST_COMPLETED)
+        while done:
+            task = done.pop()
+            result = task.result()
+            if result:
+                if client:
+                    await result.close()
+                else:
+                    client = result
+        if client:
+            while pend:
+                task = pend.pop()
+                task.cancel()
+                try:
+                    await task  # let the task cleanup
+                except asyncio.CancelledError:
+                    pass
+    return client
