@@ -527,3 +527,31 @@ class TestSourceModel(unittest.TestCase):
         attachment1.mac_addresses.extend([mac, '0:11:22:33:44:55'])
         self.assertEqual(len(attachment1.mac_addresses), 1)
         self.assertEqual(attachment1.mac_addresses[0], mac)
+
+    def test_attachment_mac_addresses_order(self):
+        """order of MAC addresses doesn't matter"""
+        mac1 = '00:11:22:33:44:55'
+        mac2 = '00:11:22:33:44:66'
+        attachment1 = Attachment()
+        attachment1.mac_addresses.append(mac1)
+        attachment1.mac_addresses.append(mac2)
+
+        attachment2 = Attachment()
+        attachment2.mac_addresses.append(mac2)
+        attachment2.mac_addresses.append(mac1)
+
+        self.assertEqual(attachment1, attachment2)
+
+    def test_attachment_network_prefix_order(self):
+        """order of network prefixesdoesn't matter"""
+        ip1 = '192.0.2.1'
+        ip2 = '192.0.2.2'
+        attachment1 = Attachment()
+        attachment1.network_prefixes.append(ip1)
+        attachment1.network_prefixes.append(ip2)
+
+        attachment2 = Attachment()
+        attachment2.network_prefixes.append(ip2)
+        attachment2.network_prefixes.append(ip1)
+
+        self.assertEqual(attachment1, attachment2)
